---
feature_story: FS_61_67_08_53
feature_title: non-searchable `arg_value`
feature_status: TBD
---

Some `command_arg`-s have non-searchable `arg_value`-s:
there is no way to index corresponding `prop_value`-s from `data_envelope`-s.

Examples:

*   Data non-accessible to server:

    If there is a func to download a file,
    remote file path is such a `command_arg`
    (not part of indexed data server can load).

*   Data with huge value space:

    If func take price as parameter,
    price can potentially be arbitrary (any value) -
    no way to index them all.

TODO: Figure out how to propagate extra Bash completion parameters to enable, for example,
      auto-completion of files and directories (done locally by Bash instead of suggestion by `argrelay` server).

TODO: Figure out how to specify interrogation step for these `arg_name`-s.
      At the moment, such args are provided without interrogation spec - user can simply add extra args
      to the command line. They will be sent to client on invocation and plugin client side can try
      to make use of them, but that is not good enough support for them.
      In addition, in the future, use FS_20_88_05_60 `dictated_arg` without
      mapping of `arg_name` to `prop_name` via FS_31_70_49_15 `search_control`.

# See also

Original issue: https://github.com/argrelay/argrelay/issues/46
